"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[1869],{81869:(t,e,n)=>{function r(){return{mangle:!1,walkTokens(t){if("link"!==t.type)return;if(!t.href.startsWith("mailto:"))return;const e=t.href.substring(7),n=function(t){let e,n,r="";const s=t.length;for(e=0;e<s;e++)n=t.charCodeAt(e),Math.random()>.5&&(n="x"+n.toString(16)),r+="&#"+n+";";return r}(e);t.href=`mailto:${n}`,1===t.tokens.length&&"text"===t.tokens[0].type&&t.tokens[0].text===e&&(t.text=n,t.tokens[0].text=n)}}}n.r(e),n.d(e,{mangle:()=>r})}}]);