"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[8060],{65313:(e,r,V)=>{V.r(r),V.d(r,{CSVDelimiter:()=>t.p,CSVDocumentWidget:()=>C.kw,CSVViewer:()=>C.A9,CSVViewerFactory:()=>C.LT,DSVModel:()=>S.DSVModel,GridSearchService:()=>C.JZ,TSVViewerFactory:()=>C._d,TextRenderConfig:()=>C.B0,parseDSV:()=>i.G,parseDSVNoQuotes:()=>i.z});var S=V(18032),i=V(48234),t=V(40930),C=V(21058)}}]);