"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[2122],{92122:(t,e,o)=>{o.r(e),o.d(e,{default:()=>i});var a=o(23295),l=o(82426),n=o(53312),r=o(12030);const s={id:"@jupyterlab/cell-toolbar-extension:plugin",description:"Add the cells toolbar.",autoStart:!0,activate:async(t,e,o,a)=>{const i=e&&o?(0,n.createToolbarFactory)(o,e,l.CellBarExtension.FACTORY_NAME,s.id,null!=a?a:r.nullTranslator):void 0;t.docRegistry.addWidgetExtension("Notebook",new l.CellBarExtension(t.commands,i))},optional:[a.ISettingRegistry,n.IToolbarWidgetRegistry,r.ITranslator]},i=s}}]);